@@ -26,7 +26,6 @@
 #include <math.h>
 #include <errno.h>
 
-#include <libtracker-common/tracker-date-time.h>
 #include <libtracker-common/tracker-locale.h>
 
 #include <libtracker-sparql/tracker-sparql.h>
@@ -152,11 +151,6 @@ enum {
 	PROP_RO
 };
 
-enum {
-	TRACKER_DB_CURSOR_PROP_0,
-	TRACKER_DB_CURSOR_PROP_N_COLUMNS
-};
-
 G_DEFINE_TYPE_WITH_CODE (TrackerDBInterface, tracker_db_interface, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (G_TYPE_INITABLE,
                                                 tracker_db_interface_initable_iface_init));
@@ -403,30 +397,6 @@ function_sparql_uri_is_descendant (sqlite3_context *context,
 	sqlite3_result_int (context, match);
 }
 
-static void
-function_sparql_format_time (sqlite3_context *context,
-                             int              argc,
-                             sqlite3_value   *argv[])
-{
-	gdouble seconds;
-	gchar *str;
-
-	if (argc != 1) {
-		sqlite3_result_error (context, "Invalid argument count", -1);
-		return;
-	}
-
-	if (sqlite3_value_type (argv[0]) == SQLITE_NULL) {
-		sqlite3_result_null (context);
-		return;
-	}
-
-	seconds = sqlite3_value_double (argv[0]);
-	str = tracker_date_to_string (seconds);
-
-	sqlite3_result_text (context, str, -1, g_free);
-}
-
 static void
 function_sparql_cartesian_distance (sqlite3_context *context,
                                     int              argc,
@@ -888,10 +858,6 @@ open_database (TrackerDBInterface  *db_interface,
 	                         db_interface, &function_sparql_case_fold,
 	                         NULL, NULL);
 
-	sqlite3_create_function (db_interface->db, "SparqlFormatTime", 1, SQLITE_ANY,
-	                         db_interface, &function_sparql_format_time,
-	                         NULL, NULL);
-
 	sqlite3_extended_result_codes (db_interface->db, 0);
 	sqlite3_busy_timeout (db_interface->db, 100000);
 }
@@ -1058,23 +1024,6 @@ tracker_db_interface_sqlite_reset_collator (TrackerDBInterface *db_interface)
 	}
 }
 
-static gint
-wal_hook (gpointer     user_data,
-          sqlite3     *db,
-          const gchar *db_name,
-          gint         n_pages)
-{
-	((TrackerDBWalCallback) user_data) (n_pages);
-
-	return SQLITE_OK;
-}
-
-void
-tracker_db_interface_sqlite_wal_hook (TrackerDBInterface   *interface,
-                                      TrackerDBWalCallback  callback)
-{
-	sqlite3_wal_hook (interface->db, wal_hook, callback);
-}
 
 
 static void
@@ -1416,7 +1365,9 @@ execute_stmt (TrackerDBInterface  *interface,
 			            sqlite3_errmsg (interface->db),
 			            g_strerror (errno));
 
-#ifndef DISABLE_JOURNAL
+			sqlite3_finalize (stmt);
+			sqlite3_close (interface->db);
+
 			g_unlink (interface->filename);
 
 			g_error ("SQLite experienced an error with file:'%s'. "
@@ -1427,7 +1378,6 @@ execute_stmt (TrackerDBInterface  *interface,
 			         interface->filename);
 
 			return;
-#endif /* DISABLE_JOURNAL */
 		}
 
 		if (!error) {
@@ -1626,22 +1576,6 @@ tracker_db_cursor_finalize (GObject *object)
 	G_OBJECT_CLASS (tracker_db_cursor_parent_class)->finalize (object);
 }
 
-static void
-tracker_db_cursor_get_property (GObject    *object,
-                                guint       prop_id,
-                                GValue     *value,
-                                GParamSpec *pspec)
-{
-	TrackerDBCursor *cursor = TRACKER_DB_CURSOR (object);
-	switch (prop_id) {
-	case TRACKER_DB_CURSOR_PROP_N_COLUMNS:
-		g_value_set_int (value, tracker_db_cursor_get_n_columns (cursor));
-		break;
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	}
-}
-
 static void
 tracker_db_cursor_iter_next_thread (GSimpleAsyncResult *res,
                                     GObject            *object,
@@ -1692,7 +1626,6 @@ tracker_db_cursor_class_init (TrackerDBCursorClass *class)
 	TrackerSparqlCursorClass *sparql_cursor_class = TRACKER_SPARQL_CURSOR_CLASS (class);
 
 	object_class->finalize = tracker_db_cursor_finalize;
-	object_class->get_property = tracker_db_cursor_get_property;
 
 	sparql_cursor_class->get_value_type = (TrackerSparqlValueType (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_value_type;
 	sparql_cursor_class->get_variable_name = (const gchar * (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_variable_name;
@@ -1706,8 +1639,6 @@ tracker_db_cursor_class_init (TrackerDBCursorClass *class)
 	sparql_cursor_class->get_integer = (gint64 (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_int;
 	sparql_cursor_class->get_double = (gdouble (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_double;
 	sparql_cursor_class->get_boolean = (gboolean (*) (TrackerSparqlCursor *, gint)) tracker_db_cursor_get_boolean;
-
-	g_object_class_override_property (object_class, TRACKER_DB_CURSOR_PROP_N_COLUMNS, "n-columns");
 }
 
 static TrackerDBCursor *
