@@ -74,22 +74,9 @@ typedef struct {
 	const gchar *city;
 	const gchar *state;
 	const gchar *address;
-	const gchar *country;
-	const gchar *gps_altitude;
-	const gchar *gps_latitude;
-	const gchar *gps_longitude;
-	const gchar *gps_direction;
+	const gchar *country; 
 } MergeData;
 
-static void extract_jpeg (const gchar          *filename,
-                          TrackerSparqlBuilder *preupdate,
-                          TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "image/jpeg", extract_jpeg },
-	{ NULL, NULL }
-};
-
 struct tej_error_mgr {
 	struct jpeg_error_mgr jpeg;
 	jmp_buf setjmp_buffer;
@@ -103,49 +90,12 @@ extract_jpeg_error_exit (j_common_ptr cinfo)
 	longjmp (h->setjmp_buffer, 1);
 }
 
-static gboolean
-guess_dlna_profile (gint          width,
-                    gint          height,
-                    const gchar **dlna_profile,
-                    const gchar **dlna_mimetype)
-{
-	gchar *profile = NULL;
-
-	if (dlna_profile) {
-		*dlna_profile = NULL;
-	}
-
-	if (dlna_mimetype) {
-		*dlna_mimetype = NULL;
-	}
-
-	if (width <= 640 && height <= 480) {
-		profile = "JPEG_SM";
-	} else if (width <= 1024 && height <= 768) {
-		profile = "JPEG_MED";
-	} else if (width <= 4096 && height <= 4096) {
-		profile = "JPEG_LRG";
-	}
-
-	if (profile) {
-		if (dlna_profile) {
-			*dlna_profile = profile;
-		}
-
-		if (dlna_mimetype) {
-			*dlna_mimetype = "image/jpeg";
-		}
-
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static void
-extract_jpeg (const gchar          *uri,
-              TrackerSparqlBuilder *preupdate,
-              TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	struct jpeg_decompress_struct cinfo;
 	struct tej_error_mgr tejerr;
@@ -158,10 +108,9 @@ extract_jpeg (const gchar          *uri,
 	goffset size;
 	gchar *filename;
 	gchar *comment = NULL;
-	const gchar *dlna_profile, *dlna_mimetype;
 	GPtrArray *keywords;
+	gboolean success = TRUE;
 	guint i;
-	GString *where = NULL;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
@@ -169,14 +118,14 @@ extract_jpeg (const gchar          *uri,
 
 	if (size < 18) {
 		g_free (filename);
-		return;
+		return FALSE;
 	}
 
-	f = tracker_file_open (filename);
+	f = tracker_file_open (filename, "rb", FALSE);
 	g_free (filename);
 
 	if (!f) {
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -187,6 +136,7 @@ extract_jpeg (const gchar          *uri,
 	cinfo.err = jpeg_std_error (&tejerr.jpeg);
 	tejerr.jpeg.error_exit = extract_jpeg_error_exit;
 	if (setjmp (tejerr.setjmp_buffer)) {
+		success = FALSE;
 		goto fail;
 	}
 
@@ -296,12 +246,6 @@ extract_jpeg (const gchar          *uri,
 	md.state = tracker_coalesce_strip (2, xd->state, id->state);
 	md.address = tracker_coalesce_strip (2, xd->address, id->sublocation);
 	md.country = tracker_coalesce_strip (2, xd->country, id->country_name);
-
-	/* FIXME We are not handling the altitude ref here for xmp */
-	md.gps_altitude = tracker_coalesce_strip (2, xd->gps_altitude, ed->gps_altitude);
-	md.gps_latitude = tracker_coalesce_strip (2, xd->gps_latitude, ed->gps_latitude);
-	md.gps_longitude = tracker_coalesce_strip (2, xd->gps_longitude, ed->gps_longitude);
-	md.gps_direction = tracker_coalesce_strip (2, xd->gps_direction, ed->gps_direction);
 	md.creator = tracker_coalesce_strip (3, xd->creator, id->byline, id->credit);
 	md.comment = tracker_coalesce_strip (2, comment, ed->user_comment);
 	md.make = tracker_coalesce_strip (2, xd->make, ed->make);
@@ -316,13 +260,6 @@ extract_jpeg (const gchar          *uri,
 	tracker_sparql_builder_predicate (metadata, "nfo:height");
 	tracker_sparql_builder_object_int64 (metadata, cinfo.image_height);
 
-	if (guess_dlna_profile (cinfo.image_width, cinfo.image_height, &dlna_profile, &dlna_mimetype)) {
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaProfile");
-		tracker_sparql_builder_object_string (metadata, dlna_profile);
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaMime");
-		tracker_sparql_builder_object_string (metadata, dlna_mimetype);
-	}
-
 	if (id->contact) {
 		gchar *uri = tracker_sparql_escape_uri_printf ("urn:contact:%s", id->contact);
 
@@ -414,10 +351,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
-        if (xd->regions) {
-	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-        }
-
 	if (id->keywords) {
 		tracker_keywords_parse (keywords, id->keywords);
 	}
@@ -444,10 +377,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -614,75 +543,52 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, md.comment);
 	}
 
-	if (md.address || md.state || md.country || md.city ||
-	    md.gps_altitude || md.gps_latitude || md.gps_longitude) {
+	if (md.city || md.state || md.address || md.country) {
+		gchar *addruri;
 
 		tracker_sparql_builder_predicate (metadata, "slo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata); /* GeoPoint */
+		tracker_sparql_builder_object_blank_open (metadata); /* GeoLocation */
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "slo:GeoLocation");
 
-		if (md.address || md.state || md.country || md.city) {
-			gchar *addruri;
+		addruri = tracker_sparql_get_uuid_urn ();
 
-			addruri = tracker_sparql_get_uuid_urn ();
-
-			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);
-
-			tracker_sparql_builder_insert_open (preupdate, NULL);
-			tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-			g_free (addruri);
-
-			tracker_sparql_builder_predicate (preupdate, "a");
-			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-			if (md.address) {
-				tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.address);
-			}
-
-			if (md.state) {
-				tracker_sparql_builder_predicate (preupdate, "nco:region");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.state);
-			}
-
-			if (md.city) {
-				tracker_sparql_builder_predicate (preupdate, "nco:locality");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.city);
-			}
-
-			if (md.country) {
-				tracker_sparql_builder_predicate (preupdate, "nco:country");
-				tracker_sparql_builder_object_unvalidated (preupdate, md.country);
-			}
-
-			tracker_sparql_builder_insert_close (preupdate);
-		}
-
-		if (md.gps_altitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:altitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_altitude);
-		}
-
-		if (md.gps_latitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:latitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_latitude);
-		}
-
-		if (md.gps_longitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:longitude");
-			tracker_sparql_builder_object_unvalidated (metadata, md.gps_longitude);
-		}
+		tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
 
 		tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-	}
 
-	if (md.gps_direction) {
-		tracker_sparql_builder_predicate (metadata, "nfo:heading");
-		tracker_sparql_builder_object_unvalidated (metadata, md.gps_direction);
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (md.address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.address);
+		}
+
+		if (md.state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.state);
+		}
+
+		if (md.city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.city);
+		}
+
+		if (md.country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, md.country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
+
 	}
 
 	if (cinfo.density_unit != 0 || ed->x_resolution) {
@@ -723,11 +629,6 @@ extract_jpeg (const gchar          *uri,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	jpeg_destroy_decompress (&cinfo);
 
 	tracker_exif_free (ed);
@@ -737,10 +638,6 @@ extract_jpeg (const gchar          *uri,
 
 fail:
 	tracker_file_close (f, FALSE);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return success;
 }
