@@ -56,7 +56,6 @@ typedef struct {
 	const gchar *state;
 	const gchar *address;
 	const gchar *country;
-	const gchar *gps_direction;
 } MergeData;
 
 typedef struct {
@@ -70,16 +69,6 @@ typedef struct {
 	const gchar *disclaimer;
 } PngData;
 
-static void extract_png (const gchar          *filename,
-                         TrackerSparqlBuilder *preupdate,
-                         TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "image/png", extract_png },
-	{ "sketch/png", extract_png },
-	{ NULL, NULL }
-};
-
 static gchar *
 rfc1123_to_iso8601_date (const gchar *date)
 {
@@ -89,111 +78,10 @@ rfc1123_to_iso8601_date (const gchar *date)
 	return tracker_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
 }
 
-/* Handle raw profiles by Imagemagick (at least). Hex encoded with
- * line-changes and other (undocumented/unofficial) twists.
- */
-static gchar *
-raw_profile_new (const gchar *input,
-                 const guint  input_length,
-                 guint       *output_length)
-{
-	static const gchar* const lut = "0123456789abcdef";
-	gchar *output;
-	const gchar *ptr;
-	const gchar *length_ptr;
-	gsize size;
-	gchar *length_str;
-	guint length;
-
-	size_t len;
-	size_t i;
-	size_t o;
-	char *p;
-	char *q;
-
-	ptr = input;
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	ptr++;
-
-	if (!g_ascii_isalpha (*ptr)) {
-		return NULL;
-	}
-
-	/* Skip the type string */
-	do {
-		ptr++;
-	} while (g_ascii_isalpha (*ptr));
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	/* Hop over whitespaces */
-	do {
-		ptr++;
-	} while (*ptr == ' ');
-
-	if (!g_ascii_isdigit (*ptr)) {
-		return NULL;
-	}
-
-	/* Get the length string */
-	length_ptr = ptr;
-	size = 1;
-
-	do {
-		ptr++;
-		size++;
-	} while (g_ascii_isdigit (*ptr));
-
-	length_str = g_strndup (length_ptr, size - 1);
-
-	if (*ptr != '\n') {
-		return NULL;
-	}
-
-	ptr++;
-
-	length = atoi (length_str);
-	g_free (length_str);
-
-	len = length;
-	i = 0;
-	o = 0;
-
-	output = malloc (length + 1); /* A bit less with non-valid */
-
-	o = 0;
-	while (o < len) {
-		do {
-			gchar a = ptr[i];
-			p = strchr (lut, a);
-			i++;
-		} while (p == 0);
-
-		do {
-			gchar b = ptr[i];
-			q = strchr (lut, b);
-			i++;
-		} while (q == 0);
-
-		output[o] = (((p - lut) << 4) | (q - lut));
-		o++;
-	}
-
-	output[o] = '\0';
-	*output_length = o;
-
-	return output;
-}
-
 static void
 read_metadata (TrackerSparqlBuilder *preupdate,
                TrackerSparqlBuilder *metadata,
+               GString              *where,
                png_structp           png_ptr,
                png_infop             info_ptr,
                png_infop             end_ptr,
@@ -210,7 +98,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	gint i;
 	gint found;
 	GPtrArray *keywords;
-	GString *where = NULL;
 
 	info_ptrs[0] = info_ptr;
 	info_ptrs[1] = end_ptr;
@@ -226,74 +113,32 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 				continue;
 			}
 
-#if defined(HAVE_EXEMPI) && defined(PNG_iTXt_SUPPORTED)
+	#if defined(HAVE_EXEMPI) && defined(PNG_iTXt_SUPPORTED)
 			if (g_strcmp0 ("XML:com.adobe.xmp", text_ptr[i].key) == 0) {
 				/* ATM tracker_extract_xmp_read supports setting xd
 				 * multiple times, keep it that way as here it's
 				 * theoretically possible that the function gets
-				 * called multiple times
+				 * called multiple times 
 				 */
 				xd = tracker_xmp_new (text_ptr[i].text,
-				                      text_ptr[i].itxt_length,
-				                      uri);
-
+					              text_ptr[i].itxt_length,
+					              uri);
 				continue;
 			}
+	#endif
 
-			if (g_strcmp0 ("Raw profile type xmp", text_ptr[i].key) == 0) {
-				gchar *xmp_buffer;
-				guint xmp_buffer_length = 0;
-				guint input_len;
-
-				if (text_ptr[i].text_length) {
-					input_len = text_ptr[i].text_length;
-				} else {
-					input_len = text_ptr[i].itxt_length;
-				}
-
-				xmp_buffer = raw_profile_new (text_ptr[i].text,
-				                              input_len,
-				                              &xmp_buffer_length);
-
-				if (xmp_buffer) {
-					xd = tracker_xmp_new (xmp_buffer,
-					                      xmp_buffer_length,
-					                      uri);
-				}
-
-				g_free (xmp_buffer);
-
-				continue;
-			}
-#endif
-
-#if defined(HAVE_LIBEXIF) && defined(PNG_iTXt_SUPPORTED)
+	#if defined(HAVE_LIBEXIF) && defined(PNG_iTXt_SUPPORTED)
+			/* I'm not certain this is the key for EXIF. Using key according to
+			 * this document about exiftool:
+			 * http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/PNG.html#TextualData 
+			 */
 			if (g_strcmp0 ("Raw profile type exif", text_ptr[i].key) == 0) {
-				gchar *exif_buffer;
-				guint exif_buffer_length = 0;
-				guint input_len;
-
-				if (text_ptr[i].text_length) {
-					input_len = text_ptr[i].text_length;
-				} else {
-					input_len = text_ptr[i].itxt_length;
-				}
-
-				exif_buffer = raw_profile_new (text_ptr[i].text,
-				                               input_len,
-				                               &exif_buffer_length);
-
-				if (exif_buffer) {
-					ed = tracker_exif_new (exif_buffer,
-					                       exif_buffer_length,
-					                       uri);
-				}
-
-				g_free (exif_buffer);
-
+				ed = tracker_exif_new (text_ptr[i].text,
+					               text_ptr[i].itxt_length,
+					               uri);
 				continue;
 			}
-#endif /* HAVE_LIBEXIF */
+	#endif /* HAVE_LIBEXIF */
 
 			if (g_strcmp0 (text_ptr[i].key, "Author") == 0) {
 				pd.author = text_ptr[i].text;
@@ -566,75 +411,51 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->coverage);
 	}
 
-	if (xd->address || xd->state || xd->country || xd->city ||
-	    xd->gps_altitude || xd->gps_latitude || xd-> gps_longitude) {
+	if (xd->address || xd->country || xd->city) {
+		gchar *addruri;
 
 		tracker_sparql_builder_predicate (metadata, "slo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata); /* GeoLocation */
+		tracker_sparql_builder_object_blank_open (metadata);
 		tracker_sparql_builder_predicate (metadata, "a");
-		tracker_sparql_builder_object (metadata, "slo:GeoLocation");
+		tracker_sparql_builder_object (metadata, "slo:GeoLocation"); /* GeoLocation */
 
-		if (xd->address || xd->state || xd->country || xd->city)  {
-			gchar *addruri;
+		addruri = tracker_sparql_get_uuid_urn ();
 
-			addruri = tracker_sparql_get_uuid_urn ();
-
-			tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
-			tracker_sparql_builder_object_iri (metadata, addruri);
-
-			tracker_sparql_builder_insert_open (preupdate, NULL);
-			tracker_sparql_builder_subject_iri (preupdate, addruri);
-
-			g_free (addruri);
-
-			tracker_sparql_builder_predicate (preupdate, "a");
-			tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
-
-			if (xd->address) {
-			  tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
-			  tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
-			}
-
-			if (xd->state) {
-			  tracker_sparql_builder_predicate (preupdate, "nco:region");
-			  tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
-			}
-
-			if (xd->city) {
-			  tracker_sparql_builder_predicate (preupdate, "nco:locality");
-			  tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
-			}
-
-			if (xd->country) {
-			  tracker_sparql_builder_predicate (preupdate, "nco:country");
-			  tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
-			}
-
-			tracker_sparql_builder_insert_close (preupdate);
-		}
-
-		if (xd->gps_altitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:altitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_altitude);
-		}
-
-		if (xd->gps_latitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:latitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_latitude);
-		}
-
-		if (xd->gps_longitude) {
-			tracker_sparql_builder_predicate (metadata, "slo:longitude");
-			tracker_sparql_builder_object_unvalidated (metadata, xd->gps_longitude);
-		}
+		tracker_sparql_builder_predicate (metadata, "slo:postalAddress");
+		tracker_sparql_builder_object_iri (metadata, addruri);
 
 		tracker_sparql_builder_object_blank_close (metadata); /* GeoLocation */
-	}
 
-	if (xd->gps_direction) {
-		tracker_sparql_builder_predicate (metadata, "nfo:heading");
-		tracker_sparql_builder_object_unvalidated (metadata, xd->gps_direction);
+		tracker_sparql_builder_insert_open (preupdate, NULL);
+		tracker_sparql_builder_subject_iri (preupdate, addruri);
+
+		g_free (addruri);
+
+		tracker_sparql_builder_predicate (preupdate, "a");
+		tracker_sparql_builder_object (preupdate, "nco:PostalAddress");
+
+		if (xd->address) {
+			tracker_sparql_builder_predicate (preupdate, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->address);
+		}
+
+		if (xd->state) {
+			tracker_sparql_builder_predicate (preupdate, "nco:region");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->state);
+		}
+
+		if (xd->city) {
+			tracker_sparql_builder_predicate (preupdate, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->city);
+		}
+
+		if (xd->country) {
+			tracker_sparql_builder_predicate (preupdate, "nco:country");
+			tracker_sparql_builder_object_unvalidated (preupdate, xd->country);
+		}
+
+		tracker_sparql_builder_insert_close (preupdate);
 	}
 
 	if (ed->x_resolution) {
@@ -653,10 +474,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (xd->regions) {
-		tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-	}
-
 	for (i = 0; i < keywords->len; i++) {
 		gchar *p, *escaped, *var;
 
@@ -679,10 +496,6 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -691,54 +504,17 @@ read_metadata (TrackerSparqlBuilder *preupdate,
 	}
 	g_ptr_array_free (keywords, TRUE);
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	g_free (pd.creation_time);
 }
 
-static gboolean
-guess_dlna_profile (gint          depth,
-                    gint          width,
-                    gint          height,
-                    const gchar **dlna_profile,
-                    const gchar **dlna_mimetype)
-{
-	gchar *profile = NULL;
-
-	if (dlna_profile) {
-		*dlna_profile = NULL;
-	}
-
-	if (dlna_mimetype) {
-		*dlna_mimetype = NULL;
-	}
-
-	profile = "PNG_LRG";
-
-	if (profile) {
-		if (dlna_profile) {
-			*dlna_profile = profile;
-		}
-
-		if (dlna_mimetype) {
-			*dlna_mimetype = "image/png";
-		}
-
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static void
-extract_png (const gchar          *uri,
-             TrackerSparqlBuilder *preupdate,
-             TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	goffset size;
 	FILE *f;
@@ -750,21 +526,20 @@ extract_png (const gchar          *uri,
 	png_uint_32 width, height;
 	gint bit_depth, color_type;
 	gint interlace_type, compression_type, filter_type;
-	const gchar *dlna_profile, *dlna_mimetype;
 	gchar *filename;
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 	size = tracker_file_get_size (filename);
 
 	if (size < 64) {
-		return;
+		return FALSE;
 	}
 
-	f = tracker_file_open (filename);
+	f = tracker_file_open (filename, "r", FALSE);
 	g_free (filename);
 
 	if (!f) {
-		return;
+		return FALSE;
 	}
 
 	png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING,
@@ -773,27 +548,27 @@ extract_png (const gchar          *uri,
 	                                  NULL);
 	if (!png_ptr) {
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	info_ptr = png_create_info_struct (png_ptr);
 	if (!info_ptr) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	end_ptr = png_create_info_struct (png_ptr);
 	if (!end_ptr) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	if (setjmp (png_jmpbuf (png_ptr))) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	png_init_io (png_ptr, f);
@@ -810,7 +585,7 @@ extract_png (const gchar          *uri,
 	                   &filter_type)) {
 		png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 		tracker_file_close (f, FALSE);
-		return;
+		return FALSE;
 	}
 
 	/* Read the image. FIXME We should be able to skip this step and
@@ -837,7 +612,7 @@ extract_png (const gchar          *uri,
 	tracker_sparql_builder_object (metadata, "nfo:Image");
 	tracker_sparql_builder_object (metadata, "nmm:Photo");
 
-	read_metadata (preupdate, metadata, png_ptr, info_ptr, end_ptr, uri);
+	read_metadata (preupdate, metadata, where, png_ptr, info_ptr, end_ptr, uri);
 
 	tracker_sparql_builder_predicate (metadata, "nfo:width");
 	tracker_sparql_builder_object_int64 (metadata, width);
@@ -845,19 +620,8 @@ extract_png (const gchar          *uri,
 	tracker_sparql_builder_predicate (metadata, "nfo:height");
 	tracker_sparql_builder_object_int64 (metadata, height);
 
-	if (guess_dlna_profile (bit_depth, width, height, &dlna_profile, &dlna_mimetype)) {
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaProfile");
-		tracker_sparql_builder_object_string (metadata, dlna_profile);
-		tracker_sparql_builder_predicate (metadata, "nmm:dlnaMime");
-		tracker_sparql_builder_object_string (metadata, dlna_mimetype);
-	}
-
 	png_destroy_read_struct (&png_ptr, &info_ptr, &end_ptr);
 	tracker_file_close (f, FALSE);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return TRUE;
 }
