@@ -19,21 +19,9 @@
 
 #include "config.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
-#include <errno.h>
-#include <fcntl.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/mman.h>
 
 #include <glib.h>
-#include <glib/gstdio.h>
-
 #include <gio/gio.h>
 
 #include <libtracker-extract/tracker-extract.h>
@@ -43,22 +31,14 @@
 
 #define  TRY_LOCALE_TO_UTF8_CONVERSION 0
 
-static void extract_text (const gchar          *uri,
-                          TrackerSparqlBuilder *preupdate,
-                          TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData data[] = {
-	{ "text/*", extract_text },
-	{ NULL, NULL }
-};
-
-
 static gchar *
 get_file_content (const gchar  *uri,
                   gsize         n_bytes)
 {
-	gchar *text, *path;
-	int fd;
+	GFile *file;
+	GFileInputStream  *stream;
+	GError     *error = NULL;
+	gchar      *text;
 
 	/* If no content requested, return */
 	if (n_bytes == 0) {
@@ -66,39 +46,38 @@ get_file_content (const gchar  *uri,
 	}
 
 	/* Get filename from URI */
-	path = g_filename_from_uri (uri, NULL, NULL);
-
-	fd = g_open (path, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (path, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_message ("Could not open file '%s': %s",
+	file = g_file_new_for_uri (uri);
+	stream = g_file_read (file, NULL, &error);
+	if (error) {
+		g_message ("Could not read file '%s': %s",
 		           uri,
-		           g_strerror (errno));
-		g_free (path);
+		           error->message);
+		g_error_free (error);
+		g_object_unref (file);
+
 		return NULL;
 	}
 
 	g_debug ("  Starting to read '%s' up to %" G_GSIZE_FORMAT " bytes...",
 	         uri, n_bytes);
 
-	/* Read up to n_bytes from stream. Output is always, always valid UTF-8,
-	 * this function closes the FD.
-	 */
-	text = tracker_read_text_from_fd (fd,
-	                                  n_bytes,
-	                                  TRY_LOCALE_TO_UTF8_CONVERSION);
-	g_free (path);
+	/* Read up to n_bytes from stream. Output is always, always valid UTF-8 */
+	text = tracker_read_text_from_stream (G_INPUT_STREAM (stream),
+	                                      n_bytes,
+	                                      TRY_LOCALE_TO_UTF8_CONVERSION);
+
+	g_object_unref (stream);
+	g_object_unref (file);
 
 	return text;
 }
 
-static void
-extract_text (const gchar          *uri,
-              TrackerSparqlBuilder *preupdate,
-              TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TrackerConfig *config;
 	gchar *content;
@@ -116,10 +95,6 @@ extract_text (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, content);
 		g_free (content);
 	}
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return data;
+	return TRUE;
 }
